@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.14
+Version 2.1401
 
 =head1 SYNOPSIS
 
@@ -256,7 +256,7 @@ it under the same terms as Perl itself.
 
 package App::Greple::subst;
 
-our $VERSION = '2.14';
+our $VERSION = '2.1401';
 
 use v5.14;
 use strict;
@@ -441,6 +441,7 @@ sub subst_show_stat {
 	push @show, [ $i, $p, $hash ];
     }
     if ($opt_show_numbers) {
+	no warnings 'uninitialized';
 	printf "HIT_PATTERN=%d/%d NG=%d, OK=%d, TOTAL=%d\n",
 	    $stat{hit}, $stat{total},
 	    $stat{ng}, $stat{ok}, $stat{ng} + $stat{ok};
@@ -726,8 +727,6 @@ option --divert-stdout --prologue __PACKAGE__::divert_stdout \
 option --with-stat     --epilogue subst_show_stat
 option --stat          --divert-stdout --with-stat
 
-#mode function
-
 autoload -Msubst::dyncmap --dyncmap
 
 help	--subst-color-light light terminal color
